import { Observable, Unsubscribable } from 'rxjs';
import { DataMserviceReaderService } from './../data-mservice-reader.service';
import { Component, OnInit, Input, OnChanges, SimpleChanges } from '@angular/core';
import { FormControl, FormGroup, FormArray, FormBuilder } from '@angular/forms';
import { StreamData } from '../stream-data';

@Component({
  selector: 'app-user-details',
  templateUrl: './user-details.component.html',
  styleUrls: ['./user-details.component.css']
})
export class UserDetailsComponent
{
  enableStreaming: boolean = true;
  subject: Observable<string>;
  terminator: Unsubscribable;
  form: FormGroup;
  _deal: FormControl = new FormControl();
  readDeal: string = '';

  constructor(private fb: FormBuilder, private dataService: DataMserviceReaderService) {
    this.form = this.fb.group({
      published: true,
      credentials: this.fb.array([]),
      realDeal: '',
      deals: this.fb.array([])
    });
  }

  addCreds() {
    const creds = this.form.controls.credentials as FormArray;
    creds.push(this.fb.group({
      _username: '',
      _password: ''
    }));
  }

  listenForDeals( rdeal: string )
  {
    this.form.controls.realDeal.setValue( rdeal );
    //console.log( rdeal );
    const deals = this.form.controls.deals as FormArray;
    deals.push(this.fb.group({
      _deal: rdeal
    }));
  }

  beginStream()
  {
    //debugger
    this.subject = this.dataService.readStream();
    this.terminator = this.subject.subscribe(val => {
      this.listenForDeals(val);
    });
    this.enableStreaming = false;
  }

  cancelStream()
  {
    this.terminator.unsubscribe();
    this.enableStreaming = true;
  }
}
